==> libtangle_0.0.20100215.tar.gz: libtangle-0.0.20100215/tangle/tangle-actor.h <==

/*
 * tangle-actor.h
 *
 * This file is part of Tangle Toolkit - A graphical widget library based on Clutter Toolkit
 *
 * (c) 2009-2010 Henrik Hedberg <henrik.hedberg@innologies.fi>
 *
 */

#ifndef __TANGLE_ACTOR_H__
#define __TANGLE_ACTOR_H__

#include <clutter/clutter.h>

#define TANGLE_TYPE_ACTOR (tangle_actor_get_type())
#define TANGLE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), TANGLE_TYPE_ACTOR, TangleActor))
#define TANGLE_IS_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), TANGLE_TYPE_ACTOR))
#define TANGLE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), TANGLE_TYPE_ACTOR, TangleActorClass))
#define TANGLE_IS_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), TANGLE_TYPE_ACTOR))
#define TANGLE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), TANGLE_TYPE_ACTOR, TangleActorClass))

/**
 * TangleActorFlags:
 *
 * Addition information on the state of an actor.
 */
typedef enum {
	TANGLE_ACTOR_ON_SCREEN = 1 << 0,
	TANGLE_ACTOR_PAINTED = 1 << 1
} TangleActorFlags;

typedef struct _TangleActor TangleActor;
typedef struct _TangleActorPrivate TangleActorPrivate;

#include "tangle-event.h"

/**
 * TangleActor:
 * @flags: #TangleActorFlags
 *
 * Base class for actors.
 */
struct _TangleActor {
	ClutterActor parent_instance;

	TangleActorPrivate* priv;
	TangleActorFlags flags;
};

typedef struct _TangleActorClass {
	ClutterActorClass parent_class;
	
	ClutterAnimation* (*animate_transition)(TangleActor* actor, ClutterActorBox* current_box, ClutterActorBox* new_box);
	void (*get_preferred_width)(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
	void (*get_preferred_height)(TangleActor* actor, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
	void (*paint_aligned)(TangleActor* actor, gfloat width, gfloat height);
	void (*handle_ancestor_event)(TangleActor* actor, TangleEvent* event);
	void (*handle_descendant_event)(TangleActor* actor, TangleEvent* event);
} TangleActorClass;

GType tangle_actor_get_type (void) G_GNUC_CONST;

#define TANGLE_ACTOR_SET_FLAGS(a,f) (((TangleActor*)(a))->flags |= (f))
#define TANGLE_ACTOR_UNSET_FLAGS(a,f)  (((TangleActor*)(a))->flags &= ~(f))
#define TANGLE_ACTOR_IS_ON_SCREEN(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_ON_SCREEN) != FALSE)
#define TANGLE_ACTOR_IS_MAPPED_ON_SCREEN(a) (CLUTTER_ACTOR_IS_MAPPED(a) && ((((TangleActor*)(a))->flags & TANGLE_ACTOR_ON_SCREEN) != FALSE))
#define TANGLE_ACTOR_IS_PAINTED(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_PAINTED) != FALSE)

ClutterAnimation* tangle_actor_animate(TangleActor* actor, gulong mode, guint duration, const gchar* first_property_name, ...);

gboolean tangle_actor_should_transition_scale_children(TangleActor* actor);

void tangle_actor_hide_animated(TangleActor* actor);
void tangle_actor_hide_all_animated(TangleActor* actor);
void tangle_actor_destroy_animated(TangleActor* actor);

typedef struct {
	gfloat left;
	gfloat top;
	gfloat right;
	gfloat bottom;
} TangleSpacing;

void tangle_actor_get_margin(TangleActor* actor, TangleSpacing* spacing);
void tangle_actor_set_margin(TangleActor* actor, const TangleSpacing* spacing);
gboolean tangle_actor_get_margin_set(TangleActor* actor);
void tangle_actor_set_margin_set(TangleActor* actor, gboolean is_set);

void tangle_actor_get_max_size(TangleActor* actor, gfloat* max_width_p, gfloat* max_height_p);
void tangle_actor_set_max_size(TangleActor* actor, gfloat max_width, gfloat max_height);

gdouble tangle_actor_get_alignment_x(TangleActor* actor);
void tangle_actor_set_alignment_x(TangleActor* actor, gdouble alignment_x);
gdouble tangle_actor_get_alignment_y(TangleActor* actor);
void tangle_actor_set_alignment_y(TangleActor* actor, gdouble alignment_y);

void tangle_actor_get_aligned_allocation(TangleActor* actor, ClutterActorBox* actor_box);

gboolean tangle_actor_get_interacting(TangleActor* actor);
void tangle_actor_get_preferred_width(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
void tangle_actor_get_preferred_height(TangleActor* actor, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
void tangle_actor_get_preferred_size(TangleActor* actor, gboolean interacting, gfloat* min_width_p, gfloat* min_height_p, gfloat* natural_width_p, gfloat* natural_height_p, gfloat* max_width_p, gfloat* max_height_p);

gdouble tangle_actor_get_interactive_size_multiplier(TangleActor* actor);
void tangle_actor_set_interactive_size_multiplier(TangleActor* actor, gdouble multiplier);
gboolean tangle_actor_get_interactive_size_multiplier_set(TangleActor* actor);
void tangle_actor_set_interactive_size_multiplier_set(TangleActor* actor, gboolean is_set);

void tangle_actor_send_event(TangleActor* actor, TangleEvent* event);
void tangle_actor_handle_ancestor_event(TangleActor* actor, TangleEvent* event);
void tangle_actor_handle_descendant_event(TangleActor* actor, TangleEvent* event);

TangleSpacing* tangle_spacing_new(gfloat top, gfloat right, gfloat bottom, gfloat left);
TangleSpacing* tangle_spacing_copy(const TangleSpacing* spacing);
void tangle_spacing_free(TangleSpacing* spacing);
gboolean tangle_spacing_equal(const TangleSpacing* spacing_a, const TangleSpacing* spacing_b);


#endif

==> libtangle_0.0.20100221.tar.gz: libtangle-0.0.20100221/tangle/tangle-actor.h <==

/*
 * tangle-actor.h
 *
 * This file is part of Tangle Toolkit - A graphical widget library based on Clutter Toolkit
 *
 * (c) 2009-2010 Henrik Hedberg <henrik.hedberg@innologies.fi>
 *
 */

#ifndef __TANGLE_ACTOR_H__
#define __TANGLE_ACTOR_H__

#include <clutter/clutter.h>

#define TANGLE_TYPE_ACTOR (tangle_actor_get_type())
#define TANGLE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), TANGLE_TYPE_ACTOR, TangleActor))
#define TANGLE_IS_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), TANGLE_TYPE_ACTOR))
#define TANGLE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), TANGLE_TYPE_ACTOR, TangleActorClass))
#define TANGLE_IS_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), TANGLE_TYPE_ACTOR))
#define TANGLE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS((obj), TANGLE_TYPE_ACTOR, TangleActorClass))

/**
 * TangleActorFlags:
 *
 * Addition information on the state of an actor.
 */
typedef enum {
	TANGLE_ACTOR_ON_SCREEN = 1 << 0,
	TANGLE_ACTOR_PAINTED = 1 << 1,
	TANGLE_ACTOR_HIDING = 1 << 2
} TangleActorFlags;

typedef struct _TangleActor TangleActor;
typedef struct _TangleActorPrivate TangleActorPrivate;

#include "tangle-event.h"

/**
 * TangleActor:
 * @flags: #TangleActorFlags
 *
 * Base class for actors.
 */
struct _TangleActor {
	ClutterActor parent_instance;

	TangleActorPrivate* priv;
	TangleActorFlags flags;
};

typedef struct _TangleActorClass {
	ClutterActorClass parent_class;
	
	ClutterAnimation* (*animate_transition)(TangleActor* actor, ClutterActorBox* current_box, ClutterActorBox* new_box);
	void (*get_preferred_width)(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
	void (*get_preferred_height)(TangleActor* actor, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
	void (*paint_aligned)(TangleActor* actor, gfloat width, gfloat height);
	void (*handle_ancestor_event)(TangleActor* actor, TangleEvent* event);
	void (*handle_descendant_event)(TangleActor* actor, TangleEvent* event);
} TangleActorClass;

GType tangle_actor_get_type (void) G_GNUC_CONST;

#define TANGLE_ACTOR_SET_FLAGS(a,f) (((TangleActor*)(a))->flags |= (f))
#define TANGLE_ACTOR_UNSET_FLAGS(a,f)  (((TangleActor*)(a))->flags &= ~(f))
#define TANGLE_ACTOR_IS_ON_SCREEN(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_ON_SCREEN) != FALSE)
#define TANGLE_ACTOR_IS_MAPPED_ON_SCREEN(a) (CLUTTER_ACTOR_IS_MAPPED(a) && ((((TangleActor*)(a))->flags & TANGLE_ACTOR_ON_SCREEN) != FALSE))
#define TANGLE_ACTOR_IS_PAINTED(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_PAINTED) != FALSE)
#define TANGLE_ACTOR_IS_HIDING(a) ((((TangleActor*)(a))->flags & TANGLE_ACTOR_HIDING) != FALSE)

ClutterAnimation* tangle_actor_animate(TangleActor* actor, gulong mode, guint duration, const gchar* first_property_name, ...);

gboolean tangle_actor_should_transition_scale_children(TangleActor* actor);

void tangle_actor_show(TangleActor* actor);
void tangle_actor_hide_animated(TangleActor* actor);
void tangle_actor_hide_all_animated(TangleActor* actor);
void tangle_actor_destroy_animated(TangleActor* actor);

typedef struct {
	gfloat left;
	gfloat top;
	gfloat right;
	gfloat bottom;
} TangleSpacing;

void tangle_actor_get_margin(TangleActor* actor, TangleSpacing* spacing);
void tangle_actor_set_margin(TangleActor* actor, const TangleSpacing* spacing);
gboolean tangle_actor_get_margin_set(TangleActor* actor);
void tangle_actor_set_margin_set(TangleActor* actor, gboolean is_set);

void tangle_actor_get_max_size(TangleActor* actor, gfloat* max_width_p, gfloat* max_height_p);
void tangle_actor_set_max_size(TangleActor* actor, gfloat max_width, gfloat max_height);

gdouble tangle_actor_get_alignment_x(TangleActor* actor);
void tangle_actor_set_alignment_x(TangleActor* actor, gdouble alignment_x);
gdouble tangle_actor_get_alignment_y(TangleActor* actor);
void tangle_actor_set_alignment_y(TangleActor* actor, gdouble alignment_y);

void tangle_actor_get_aligned_allocation(TangleActor* actor, ClutterActorBox* actor_box);

gboolean tangle_actor_get_interacting(TangleActor* actor);
void tangle_actor_get_preferred_width(TangleActor* actor, gfloat for_height, gboolean interacting, gfloat* min_width_p, gfloat* natural_width_p, gfloat* max_width_p);
void tangle_actor_get_preferred_height(TangleActor* actor, gfloat for_width, gboolean interacting, gfloat* min_height_p, gfloat* natural_height_p, gfloat* max_height_p);
void tangle_actor_get_preferred_size(TangleActor* actor, gboolean interacting, gfloat* min_width_p, gfloat* min_height_p, gfloat* natural_width_p, gfloat* natural_height_p, gfloat* max_width_p, gfloat* max_height_p);

gdouble tangle_actor_get_interactive_size_multiplier(TangleActor* actor);
void tangle_actor_set_interactive_size_multiplier(TangleActor* actor, gdouble multiplier);
gboolean tangle_actor_get_interactive_size_multiplier_set(TangleActor* actor);
void tangle_actor_set_interactive_size_multiplier_set(TangleActor* actor, gboolean is_set);

void tangle_actor_send_event(TangleActor* actor, TangleEvent* event);
void tangle_actor_handle_ancestor_event(TangleActor* actor, TangleEvent* event);
void tangle_actor_handle_descendant_event(TangleActor* actor, TangleEvent* event);

TangleSpacing* tangle_spacing_new(gfloat top, gfloat right, gfloat bottom, gfloat left);
TangleSpacing* tangle_spacing_copy(const TangleSpacing* spacing);
void tangle_spacing_free(TangleSpacing* spacing);
gboolean tangle_spacing_equal(const TangleSpacing* spacing_a, const TangleSpacing* spacing_b);


#endif
